"""
PogoOCR
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

A Python tool for running OCR on Pokemon Screenshots using Google Cloud Vision

:copyright: (c) 2018 TrainerDex
:licence: Undecided, ask permission before using.

"""

__title__ = "PogoOCR"
__author__ = "JayTurnr"
__licence__ = "GNU GENERAL PUBLIC LICENSE 3.0"
__copyright__ = "2018 TrainerDex"
__version__ = "0.0.2"

from .cloudvision import *
from .types import *
